#ifndef NT2_INCLUDE_FUNCTIONS_DEFINITELY_LESS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_DEFINITELY_LESS_HPP_INCLUDED

#include <nt2/fuzzy/include/functions/definitely_less.hpp>

#endif
